"use strict";
// Copyright (c) Dharanish Kedarisetti
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("@jupyter-widgets/base");
const version_1 = require("./version");
// Import the CSS
require("../css/widget.css");
class ExampleModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: ExampleModel.model_name, _model_module: ExampleModel.model_module, _model_module_version: ExampleModel.model_module_version, _view_name: ExampleModel.view_name, _view_module: ExampleModel.view_module, _view_module_version: ExampleModel.view_module_version, value: 'Hello World' });
    }
}
exports.ExampleModel = ExampleModel;
ExampleModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
ExampleModel.model_name = 'ExampleModel';
ExampleModel.model_module = version_1.MODULE_NAME;
ExampleModel.model_module_version = version_1.MODULE_VERSION;
ExampleModel.view_name = 'ExampleView'; // Set to null if no view
ExampleModel.view_module = version_1.MODULE_NAME; // Set to null if no view
ExampleModel.view_module_version = version_1.MODULE_VERSION;
class ExampleView extends base_1.DOMWidgetView {
    render() {
        this.el.classList.add('custom-widget');
        this.value_changed();
        this.model.on('change:value', this.value_changed, this);
    }
    value_changed() {
        this.el.textContent = this.model.get('value');
    }
}
exports.ExampleView = ExampleView;
class VideoModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: VideoModel.model_name, _model_module: VideoModel.model_module, _model_module_version: VideoModel.model_module_version, _view_name: VideoModel.view_name, _view_module: VideoModel.view_module, _view_module_version: VideoModel.view_module_version, format: 'mp4', width: '', height: '', autoplay: true, muted: true, loop: true, controls: true, value: new DataView(new ArrayBuffer(0)), videoTime: 0.0 });
    }
}
exports.VideoModel = VideoModel;
VideoModel.serializers = Object.assign(Object.assign({}, base_1.DOMWidgetModel.serializers), { value: {
        serialize: (value) => {
            return new DataView(value.buffer.slice(0));
        }
    } });
VideoModel.model_name = 'VideoModel';
VideoModel.model_module = version_1.MODULE_NAME;
VideoModel.model_module_version = version_1.MODULE_VERSION;
VideoModel.view_name = 'VideoView'; // Set to null if no view
VideoModel.view_module = version_1.MODULE_NAME; // Set to null if no view
VideoModel.view_module_version = version_1.MODULE_VERSION;
class VideoView extends base_1.DOMWidgetView {
    render() {
        /**
         * Called when view is rendered.
         */
        super.render();
        this.updated(); // Set defaults.
        this.el.addEventListener('timeupdate', () => {
            this.onTrackedVideoFrame();
        });
        this.model.on('change:videoTime', this.videoTime_changed, this);
    }
    updated() {
        /**
         * Update the contents of this view
         *
         */
        let url;
        const format = this.model.get('format');
        const value = this.model.get('value');
        if (format !== 'url') {
            const blob = new Blob([value], {
                type: `video/${this.model.get('format')}`
            });
            url = URL.createObjectURL(blob);
        }
        else {
            url = new TextDecoder('utf-8').decode(value.buffer);
        }
        // Clean up the old objectURL
        const oldurl = this.el.src;
        this.el.src = url;
        if (oldurl && typeof oldurl !== 'string') {
            URL.revokeObjectURL(oldurl);
        }
        // Height and width
        const width = this.model.get('width');
        if (width !== undefined && width.length > 0) {
            this.el.setAttribute('width', width);
        }
        else {
            this.el.removeAttribute('width');
        }
        const height = this.model.get('height');
        if (height !== undefined && height.length > 0) {
            this.el.setAttribute('height', height);
        }
        else {
            this.el.removeAttribute('height');
        }
        // Video attributes
        const loop = this.model.get('loop');
        if (loop != undefined && loop) {
            this.el.setAttribute('loop', loop);
        }
        else {
            this.el.removeAttribute('loop');
        }
        const muted = this.model.get('muted');
        if (muted != undefined && muted) {
            this.el.muted = muted;
        }
        else {
            this.el.removeAttribute('muted');
        }
        const autoplay = this.model.get('autoplay');
        if (autoplay != undefined && autoplay) {
            this.el.setAttribute('autoplay', autoplay);
        }
        else {
            this.el.removeAttribute('autoplay');
        }
        const controls = this.model.get('controls');
        if (controls != undefined && controls !== false) {
            this.el.setAttribute('controls', controls);
        }
        else {
            this.el.removeAttribute('controls');
        }
        return super.update();
    }
    remove() {
        if (this.el.src) {
            URL.revokeObjectURL(this.el.src);
        }
        super.remove();
    }
    videoTime_changed() {
        console.log('------', this.model.get('videoTime'));
        this.el.currentTime = this.model.get('videoTime');
    }
    onTrackedVideoFrame() {
        this.model.set('videoTime', this.el.currentTime);
        this.touch();
        console.log(this.el.currentTime, this.model.attributes.videoTime);
    }
    /**
     * The default tag name.
     *
     * #### Notes
     * This is a read-only attribute.
     */
    get tagName() {
        // We can't make this an attribute with a default value
        // since it would be set after it is needed in the
        // constructor.
        return 'video';
    }
}
exports.VideoView = VideoView;
//# sourceMappingURL=widget.js.map